package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.XysArticleMapper;
import com.ruoyi.system.domain.XysArticle;
import com.ruoyi.system.service.IXysArticleService;

/**
 * 文章管理Service业务层处理
 *
 * @author libao
 * @date 2024-07-08
 */
@Service
public class XysArticleServiceImpl implements IXysArticleService
{
    @Autowired
    private XysArticleMapper xysArticleMapper;

    /**
     * 查询文章管理
     *
     * @param id 文章管理主键
     * @return 文章管理
     */
    @Override
    public XysArticle selectXysArticleById(Long id)
    {
        return xysArticleMapper.selectXysArticleById(id);
    }

    /**
     * 查询文章管理列表
     *
     * @param xysArticle 文章管理
     * @return 文章管理
     */
    @Override
    public List<XysArticle> selectXysArticleList(XysArticle xysArticle)
    {
        return xysArticleMapper.selectXysArticleList(xysArticle);
    }

    @Override
    public List<XysArticle> selectHomeArticleList(XysArticle xysArticle) {
        return xysArticleMapper.selectHomeArticleList(xysArticle);
    }

    /**
     * 新增文章管理
     *
     * @param xysArticle 文章管理
     * @return 结果
     */
    @Override
    public int insertXysArticle(XysArticle xysArticle)
    {
        xysArticle.setCreateTime(DateUtils.getNowDate());
        return xysArticleMapper.insertXysArticle(xysArticle);
    }

    /**
     * 修改文章管理
     *
     * @param xysArticle 文章管理
     * @return 结果
     */
    @Override
    public int updateXysArticle(XysArticle xysArticle)
    {
        xysArticle.setUpdateTime(DateUtils.getNowDate());
        return xysArticleMapper.updateXysArticle(xysArticle);
    }

    /**
     * 批量删除文章管理
     *
     * @param ids 需要删除的文章管理主键
     * @return 结果
     */
    @Override
    public int deleteXysArticleByIds(Long[] ids)
    {
        return xysArticleMapper.deleteXysArticleByIds(ids);
    }

    /**
     * 删除文章管理信息
     *
     * @param id 文章管理主键
     * @return 结果
     */
    @Override
    public int deleteXysArticleById(Long id)
    {
        return xysArticleMapper.deleteXysArticleById(id);
    }
}
